==> alg-alg-1.3.2-20180904.023733-1-sources.jar: cn/com/duiba/nezha/alg/alg/vo/BudgetDo.java <==
package cn.com.duiba.nezha.alg.alg.vo;

import java.io.Serializable;


/**
 * 广告预算消耗信息
 */
public class BudgetDo implements Serializable {

    /**
     * 广告主
     */
    private Long accountId;

    /**
     * 广告
     */
    private Long advertId;

    /**
     * 时段
     */
    private Long periodId;


    /**
     * 预算
     */
    private Long budget;

    /**
     * 消耗
     */
    private Long consumeTotal;

    /**
     * 配置ID
     */
    private Long planId;

    /**
     * 记录时间
     */
    private String time;

    /**
     * 时段开始时间
     */
    private String startTime;

    /**
     * 时段结束时间
     */
    private String endTime;


    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getPeriodId() {
        return periodId;
    }

    public void setPeriodId(Long periodId) {
        this.periodId = periodId;
    }

    public Long getBudget() {
        return budget;
    }

    public void setBudget(Long budget) {
        this.budget = budget;
    }


    public Long getConsumeTotal() {
        return consumeTotal;
    }

    public void setConsumeTotal(Long consumeTotal) {
        this.consumeTotal = consumeTotal;
    }


    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }


    public String getTime() {
        return time;
    }

    public void setTime(String time) {
        this.time = time;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }


    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }


}

==> alg-alg-1.9.1-20190227.015929-1-sources.jar: cn/com/duiba/nezha/alg/alg/vo/BudgetDo.java <==
package cn.com.duiba.nezha.alg.alg.vo;

import java.io.Serializable;


/**
 * 广告预算消耗信息
 */
public class BudgetDo implements Serializable {

    /**
     * 广告主
     */
    private Long accountId;

    /**
     * 广告
     */
    private Long advertId;
    /**
     * 媒体
     */
    private Long appId;


    /**
     * 时段
     */
    private Long periodId;

    /**
     * 预算类型
     */
    private Long budgetType;

    /**
     * 平滑时段类型
     */
    private Long timeType;


    /**
     * 预算
     */
    private Long budget;

    /**
     * 消耗
     */
    private Long consumeTotal;

    /**
     * 配置ID
     */
    private Long planId;

    /**
     * 记录时间
     */
    private String time;

    /**
     * 时段开始时间
     */
    private String startTime;

    /**
     * 时段结束时间
     */
    private String endTime;




    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getPeriodId() {
        return periodId;
    }

    public void setPeriodId(Long periodId) {
        this.periodId = periodId;
    }

    public Long getBudget() {
        return budget;
    }

    public void setBudget(Long budget) {
        this.budget = budget;
    }


    public Long getConsumeTotal() {
        return consumeTotal;
    }

    public void setConsumeTotal(Long consumeTotal) {
        this.consumeTotal = consumeTotal;
    }


    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }


    public String getTime() {
        return time;
    }

    public void setTime(String time) {
        this.time = time;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }


    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getBudgetType() {
        return budgetType;
    }

    public void setBudgetType(Long budgetType) {
        this.budgetType = budgetType;
    }

    public Long getTimeType() {
        return timeType;
    }

    public void setTimeType(Long timeType) {
        this.timeType = timeType;
    }
}
